==> java-mcsv-0.0.2-sources.jar: com/github/jferard/javamcsv/processor/FieldProcessor.java <==
/*
 * java-mcsv - A MetaCSV library for Java
 *     Copyright (C) 2020-2021 J. Férard <https://github.com/jferard>
 *
 * This file is part of java-mcsv.
 *
 * java-mcsv is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * java-mcsv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *  for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses />.
 */

package com.github.jferard.javamcsv.processor;/*
 * java-mcsv - A MetaCSV library for Java
 *     Copyright (C) 2020 J. Férard <https://github.com/jferard>
 *
 * This file is part of java-mcsv.
 *
 * java-mcsv is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * java-mcsv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *  for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses />.
 */

import com.github.jferard.javamcsv.MetaCSVReadException;

public interface FieldProcessor<T> {
    /**
     * Prepare a value for a consumer
     * @param text the CSV value
     * @return the Object
     * @throws MetaCSVReadException if the text can't be converted to a T value.
     */
    T toObject(String text) throws MetaCSVReadException;

    /**
     * Prepare a value for CSV file.
     * @param value the value
     * @return the String representation of the value in the CSV file
     */
    String toString(T value);

    /**
     * For lenient writer: cast an objet to T type
     * @param o the object
     * @return the value
     */
    T cast(Object o);
}

==> java-mcsv-0.0.4-sources.jar: com/github/jferard/javamcsv/processor/FieldProcessor.java <==
/*
 * java-mcsv - A MetaCSV library for Java
 *     Copyright (C) 2020-2021 J. Férard <https://github.com/jferard>
 *
 * This file is part of java-mcsv.
 *
 * java-mcsv is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * java-mcsv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *  for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses />.
 */

package com.github.jferard.javamcsv.processor;/*
 * java-mcsv - A MetaCSV library for Java
 *     Copyright (C) 2020 J. Férard <https://github.com/jferard>
 *
 * This file is part of java-mcsv.
 *
 * java-mcsv is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * java-mcsv is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *  for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses />.
 */

import com.github.jferard.javamcsv.MetaCSVReadException;

import java.io.IOException;

public interface FieldProcessor<T> {
    /**
     * Prepare a value for a consumer
     * @param text the CSV value
     * @return the Object
     * @throws MetaCSVReadException if the text can't be converted to a T value.
     */
    T toObject(String text) throws MetaCSVReadException;

    /**
     * Prepare a value for CSV file.
     * @param value the value
     * @return the String representation of the value in the CSV file
     */
    String toString(T value);

    /**
     * Prepare a value for a canonical String
     * @param text the text value
     * @return the canonical String representation of the text.
     * @throws MetaCSVReadException if the text can't be converted to a T value.
     */
    String toCanonicalString(String text) throws MetaCSVReadException;

    /**
     * For lenient writer: cast an objet to T type
     * @param o the object
     * @return the value
     */
    T cast(Object o);
}
